@@ -1,5 +1,5 @@
 /*
- *  (c) copyright 2003-2007 Amichai Rothman
+ *  (c) copyright 2003-2009 Amichai Rothman
  *
  *  This file is part of the Java TNEF package.
  *
@@ -34,8 +34,8 @@ import java.util.*;
  * thus the getValue() method returns different types of objects. The object
  * returned is determined by the attribute type, except for several special cases.
  *
- * @author  Amichai Rothman
- * @since   2003-04-25
+ * @author Amichai Rothman
+ * @since 2003-04-25
  */
 public class Attr {
 
@@ -91,9 +91,8 @@ public class Attr {
         attTnefVersion              = /*ATT( atpDword,*/      0x9006/*)*/,
         attOemCodepage              = /*ATT( atpByte,*/       0x9007/*)*/,
         attOriginalMessageClass     = /*ATT( atpWord,*/       0x0006/*)*/, /* PR_ORIG_MESSAGE_CLASS */
-
         attOwner                    = /*ATT( atpByte,*/       0x0000/*)*/, /* PR_RCVD_REPRESENTING_xxx  or
-                                                                               PR_SENT_REPRESENTING_xxx */
+                                                                              PR_SENT_REPRESENTING_xxx */
         attSentFor                  = /*ATT( atpByte,*/       0x0001/*)*/, /* PR_SENT_REPRESENTING_xxx */
         attDelegate                 = /*ATT( atpByte,*/       0x0002/*)*/, /* PR_RCVD_REPRESENTING_xxx */
         attDateStart                = /*ATT( atpDate,*/       0x0006/*)*/, /* PR_DATE_START */
@@ -143,7 +142,7 @@ public class Attr {
     /**
      * Gets the Attr level.
      *
-     * @return the Attr level.
+     * @return the Attr level
      */
     public byte getLevel() {
         return this.level;
@@ -152,7 +151,7 @@ public class Attr {
     /**
      * Gets the Attr type.
      *
-     * @return the Attr type.
+     * @return the Attr type
      */
     public int getType() {
         return this.type;
@@ -161,7 +160,7 @@ public class Attr {
     /**
      * Gets the Attr ID.
      *
-     * @return the Attr ID.
+     * @return the Attr ID
      */
     public int getID() {
         return this.ID;
@@ -170,7 +169,7 @@ public class Attr {
     /**
      * Gets the Attr data length (in bytes).
      *
-     * @return the Attr data length (in bytes), or -1 if it is unknown.
+     * @return the Attr data length (in bytes), or -1 if it is unknown
      */
     public int getLength() {
         return this.length;
@@ -179,7 +178,7 @@ public class Attr {
     /**
      * Gets the Attr raw data.
      *
-     * @return the Attr raw data.
+     * @return the Attr raw data
      */
     public RawInputStream getRawData() {
         return this.rawData;
@@ -188,7 +187,7 @@ public class Attr {
     /**
      * Returns a string representation of this object.
      *
-     * @return a string representation of this object.
+     * @return a string representation of this object
      */
     public String toString() {
         StringBuffer s = new StringBuffer();
@@ -198,24 +197,24 @@ public class Attr {
             .append(" ID=").append(TNEFUtils.getConstName(this.getClass(),"att",getID()))
             .append(" length=").append(getLength());
             s.append(" value=");
-            try {
-                Object o = getValue();
+        try {
+            Object o = getValue();
 
-                if (o instanceof MAPIProps[]) {
-                    MAPIProps[] props = (MAPIProps[])o;
-                    for (int i = 0; i < props.length; i++)
-                        for (int j = 0; j < props[i].getProps().length; j++)
-                            s.append("\n  #").append(i).append(": ").append(props[i].getProps()[j]);
-                } else if (o instanceof MAPIProps) {
-                    MAPIProp[] props = ((MAPIProps)o).getProps();
-                    for (int i = 0; i < props.length; i++)
-                        s.append("\n  ").append(props[i]);
-                } else {
-                    s.append(o);
-                }
-            } catch (IOException ioe) {
-                s.append("INVALID VALUE: ").append(ioe);
+            if (o instanceof MAPIProps[]) {
+                MAPIProps[] props = (MAPIProps[])o;
+                for (int i = 0; i < props.length; i++)
+                    for (int j = 0; j < props[i].getProps().length; j++)
+                        s.append("\n  #").append(i).append(": ").append(props[i].getProps()[j]);
+            } else if (o instanceof MAPIProps) {
+                MAPIProp[] props = ((MAPIProps)o).getProps();
+                for (int i = 0; i < props.length; i++)
+                    s.append("\n  ").append(props[i]);
+            } else {
+                s.append(o);
             }
+        } catch (IOException ioe) {
+            s.append("INVALID VALUE: ").append(ioe);
+        }
         return s.toString();
     }
 
@@ -226,7 +225,8 @@ public class Attr {
      * returned is determined by the attribute type, except for several special cases.
      * The returned Object should be cast into the appropriate class.
      *
-     * @return the value of the Attr's data.
+     * @return the value of the Attr's data
+     * @throws IOException if an I/O error occurs
      */
     public Object getValue() throws IOException {
         if (rawData != null)
@@ -241,7 +241,7 @@ public class Attr {
      * @throws IOException if an I/O error occurs
      */
     protected void read(RawInputStream in) throws IOException {
-        RawInputStream ris = new RawInputStream(this.rawData); // a new copy each time!
+        RawInputStream ris = new RawInputStream(in); // a new copy each time!
         Object o = null;
 
         // first handle special attributes
@@ -267,7 +267,7 @@ public class Attr {
                 o = recipients;
                 break;
             case attMAPIProps:
-                    o = new MAPIProps(ris);
+                o = new MAPIProps(ris);
                 break;
         }
 
@@ -315,10 +315,10 @@ public class Attr {
     /**
      * Finds an attribute with the specified ID within given attribute list.
      *
-     * @param   attributes the attribute list to search
-     * @param   ID the ID of the attribute to search for
-     * @return  an attribute with given ID found in the attribute list,
-     *          or null if no such attribute exists.
+     * @param attributes the attribute list to search
+     * @param ID the ID of the attribute to search for
+     * @return an attribute with given ID found in the attribute list,
+     *         or null if no such attribute exists
      */
     public static Attr findAttr(List attributes, int ID) {
         Attr attr = null;
